@@ -2,6 +2,7 @@
  * This file is part of nzbget. See <https://nzbget.com>.
  *
  * Copyright (C) 2012-2019 Andrey Prygunkov <hugbug@users.sourceforge.net>
+ * Copyright (C) 2025 Denis <denis@nzbget.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -241,6 +242,7 @@ var Upload = (new function($)
 		$('#AddDialog_FilesHelp').show();
 		$('#AddDialog_URLLabel img').hide();
 		$('#AddDialog_URLLabel i').hide();
+		$('#AddDialog_AutoCategory').prop('checked', false);
 		$('#AddDialog_Paused').prop('checked', false);
 		$('#AddDialog_DupeForce').prop('checked', false);
 		enableAllButtons();
@@ -343,32 +345,31 @@ var Upload = (new function($)
 		var reader = new FileReader();
 		reader.onload = function (event)
 		{
-			var base64str;
-			if (reader.readAsBinaryString)
-			{
-				base64str = window.btoa(event.target.result);
-			}
-			else
-			{
-				base64str = event.target.result.replace(/^data:[^,]+,/, '');
-			}
+			var result = event.target.result;
+			var base64str = result.replace(/^data:[^,]+,/, '');
 			var category = $('#AddDialog_Category').val();
 			var priority = parseInt($('#AddDialog_Priority').val());
 			var filename = info.name + info.ext;
 			var addPaused = $('#AddDialog_Paused').is(':checked');
+			var autoCategory = $('#AddDialog_AutoCategory').is(':checked');
 			var dupeMode = $('#AddDialog_DupeForce').is(':checked') ? "FORCE" : "SCORE";
 			var params = info.password === '' ? [] : [{'*Unpack:Password' : info.password}];
-			RPC.call('append', [filename, base64str, category, priority, false, addPaused, info.dupekey, info.dupescore, dupeMode, params], fileCompleted, fileFailure);
+			RPC.call('append', [
+				filename,
+				base64str,
+				category,
+				priority,
+				false,
+				addPaused,
+				info.dupekey,
+				info.dupescore,
+				dupeMode,
+				autoCategory,
+				params,
+			], fileCompleted, fileFailure);
 		};
 
-		if (reader.readAsBinaryString)
-		{
-			reader.readAsBinaryString(file);
-		}
-		else
-		{
-			reader.readAsDataURL(file);
-		}
+		reader.readAsDataURL(file);
 	}
 
 	function fileCompleted(result)
@@ -410,10 +411,23 @@ var Upload = (new function($)
 		
 		var category = $('#AddDialog_Category').val();
 		var priority = parseInt($('#AddDialog_Priority').val());
+		var autoCategory = $('#AddDialog_AutoCategory').is(':checked');
 		var addPaused = $('#AddDialog_Paused').is(':checked');
 		var dupeMode = $('#AddDialog_DupeForce').is(':checked') ? "FORCE" : "SCORE";
 		var params = urlInfo.password === '' ? [] : [{'*Unpack:Password' : urlInfo.password}];
-		RPC.call('append', [urlInfo.name, url, category, priority, false, addPaused, urlInfo.dupekey, urlInfo.dupescore, dupeMode, params], urlCompleted, urlFailure);
+		RPC.call('append', [
+			urlInfo.name,
+			url,
+			category,
+			priority,
+			false,
+			addPaused,
+			urlInfo.dupekey,
+			urlInfo.dupescore,
+			dupeMode,
+			autoCategory,
+			params,
+		], urlCompleted, urlFailure);
 	}
 
 	function urlCompleted(result)
